from setuptools import setup

setup(
    name='algorum-quant-client-py3',
    version='1.0.25',
    packages=['AlgorumQuantClient'],
    url='https://github.com/algorum/AlgorumQuantClientPython3',
    license='MIT',
    author='Adityanand Pasumarthi',
    author_email='aditya.pasumarthi@algorum.in',
    description='Algorum Quant Client Package'
)
